==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata } from "./WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeMoveEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebFloatingPaneResizeMoveEventArgsDetail");
        }
        static d(a) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
            a.ac("WebFloatingPaneResizeMoveEventArgs", () => new WebFloatingPaneResizeMoveEventArgsDescription());
            a.ab("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata } from "./WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeMoveEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            WebFloatingPaneResizeMoveEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebFloatingPaneResizeMoveEventArgsDetail");
        }
        static d(a) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
            a.ae("WebFloatingPaneResizeMoveEventArgs", () => new WebFloatingPaneResizeMoveEventArgsDescription());
            a.ad("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
})();
